Module: Google::Ads::DataManager
- Defined in:
- lib/google/ads/data_manager.rb,
lib/google/ads/data_manager/version.rb
Constant Summary collapse
- VERSION =
"0.4.0"
Class Method Summary collapse
-
.ingestion_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for IngestionService.
-
.ingestion_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the IngestionService service is supported by the current client.
-
.marketing_data_insights_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for MarketingDataInsightsService.
-
.marketing_data_insights_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the MarketingDataInsightsService service is supported by the current client.
-
.partner_link_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PartnerLinkService.
-
.partner_link_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the PartnerLinkService service is supported by the current client.
-
.user_list_direct_license_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListDirectLicenseService.
-
.user_list_direct_license_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListDirectLicenseService service is supported by the current client.
-
.user_list_global_license_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListGlobalLicenseService.
-
.user_list_global_license_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListGlobalLicenseService service is supported by the current client.
-
.user_list_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListService.
-
.user_list_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListService service is supported by the current client.
Class Method Details
.ingestion_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for IngestionService.
By default, this returns an instance of
Google::Ads::DataManager::V1::IngestionService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the IngestionService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the IngestionService service. You can determine whether the method will succeed by calling ingestion_service_available?.
About IngestionService
Service for sending audience data to supported destinations.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/google/ads/data_manager.rb', line 57 def self.ingestion_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:IngestionService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.ingestion_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the IngestionService service is supported by the current client. If true, you can retrieve a client object by calling ingestion_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the IngestionService service, or if the versioned client gem needs an update to support the IngestionService service.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/google/ads/data_manager.rb', line 81 def self.ingestion_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :IngestionService service_module = service_module.const_get :IngestionService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.marketing_data_insights_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for MarketingDataInsightsService.
By default, this returns an instance of
Google::Ads::DataManager::V1::MarketingDataInsightsService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the MarketingDataInsightsService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the MarketingDataInsightsService service. You can determine whether the method will succeed by calling marketing_data_insights_service_available?.
About MarketingDataInsightsService
Service to return insights on marketing data.
This feature is only available to data partners.
129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/ads/data_manager.rb', line 129 def self.marketing_data_insights_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:MarketingDataInsightsService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.marketing_data_insights_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the MarketingDataInsightsService service is supported by the current client. If true, you can retrieve a client object by calling marketing_data_insights_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the MarketingDataInsightsService service, or if the versioned client gem needs an update to support the MarketingDataInsightsService service.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/google/ads/data_manager.rb', line 153 def self.marketing_data_insights_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :MarketingDataInsightsService service_module = service_module.const_get :MarketingDataInsightsService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.partner_link_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PartnerLinkService.
By default, this returns an instance of
Google::Ads::DataManager::V1::PartnerLinkService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the PartnerLinkService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PartnerLinkService service. You can determine whether the method will succeed by calling partner_link_service_available?.
About PartnerLinkService
Service for managing partner links.
199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/google/ads/data_manager.rb', line 199 def self.partner_link_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:PartnerLinkService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.partner_link_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the PartnerLinkService service is supported by the current client. If true, you can retrieve a client object by calling partner_link_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PartnerLinkService service, or if the versioned client gem needs an update to support the PartnerLinkService service.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/google/ads/data_manager.rb', line 223 def self.partner_link_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :PartnerLinkService service_module = service_module.const_get :PartnerLinkService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.user_list_direct_license_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListDirectLicenseService.
By default, this returns an instance of
Google::Ads::DataManager::V1::UserListDirectLicenseService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the UserListDirectLicenseService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the UserListDirectLicenseService service. You can determine whether the method will succeed by calling user_list_direct_license_service_available?.
About UserListDirectLicenseService
Service for managing user list direct licenses. Delete is not a supported operation for UserListDirectLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.
This feature is only available to data partners.
273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/google/ads/data_manager.rb', line 273 def self.user_list_direct_license_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:UserListDirectLicenseService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.user_list_direct_license_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListDirectLicenseService service is supported by the current client. If true, you can retrieve a client object by calling user_list_direct_license_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the UserListDirectLicenseService service, or if the versioned client gem needs an update to support the UserListDirectLicenseService service.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/google/ads/data_manager.rb', line 297 def self.user_list_direct_license_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :UserListDirectLicenseService service_module = service_module.const_get :UserListDirectLicenseService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.user_list_global_license_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListGlobalLicenseService.
By default, this returns an instance of
Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the UserListGlobalLicenseService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the UserListGlobalLicenseService service. You can determine whether the method will succeed by calling user_list_global_license_service_available?.
About UserListGlobalLicenseService
Service for managing user list global licenses. Delete is not a supported operation for UserListGlobalLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.
This feature is only available to data partners.
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/google/ads/data_manager.rb', line 347 def self.user_list_global_license_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:UserListGlobalLicenseService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.user_list_global_license_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListGlobalLicenseService service is supported by the current client. If true, you can retrieve a client object by calling user_list_global_license_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the UserListGlobalLicenseService service, or if the versioned client gem needs an update to support the UserListGlobalLicenseService service.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/google/ads/data_manager.rb', line 371 def self.user_list_global_license_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :UserListGlobalLicenseService service_module = service_module.const_get :UserListGlobalLicenseService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.user_list_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserListService.
By default, this returns an instance of
Google::Ads::DataManager::V1::UserListService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the UserListService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the UserListService service. You can determine whether the method will succeed by calling user_list_service_available?.
About UserListService
Service for managing UserList resources.
417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/google/ads/data_manager.rb', line 417 def self.user_list_service version: :v1, transport: :grpc, &block require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Ads::DataManager.const_get(package_name).const_get(:UserListService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.user_list_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the UserListService service is supported by the current client. If true, you can retrieve a client object by calling user_list_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the UserListService service, or if the versioned client gem needs an update to support the UserListService service.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/google/ads/data_manager.rb', line 441 def self.user_list_service_available? version: :v1, transport: :grpc require "google/ads/data_manager/#{version.to_s.downcase}" package_name = Google::Ads::DataManager .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Ads::DataManager.const_get package_name return false unless service_module.const_defined? :UserListService service_module = service_module.const_get :UserListService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |